@@ -8,6 +8,7 @@ import time
 from config_rss import *
 
 from rumpy import FullNode
+import rumpy.utils as utils
 
 sys.path.insert(0, RUMPY_PATH)
 sys.path.insert(0, MIXIN_SDK_PATH)
@@ -47,7 +48,7 @@ class BlazeBot:
                 self.rum.group_id = _gid
                 groups[_gid] = {
                     "group_id": _gid,
-                    "group_name": self.rum.api.seed().get("group_name"),
+                    "group_name": utils.group_name(self.rum.api.seed(_gid)["seed"]),
                     "minutes": RSS_BOT_COMMANDS[k].get("minutes") or DEFAULT_MINUTES,
                 }
         return groups
